@@ -32,10 +32,12 @@ class FindTextWidget(QWidget):
 
         self.__prevBtn = SvgButton()
         self.__prevBtn.setIcon('ico/prev.svg')
+        self.__prevBtn.setShortcut('Ctrl+Shift+D')
 
         self.__nextBtn = SvgButton()
         self.__nextBtn.setShortcut('Enter')
         self.__nextBtn.setIcon('ico/next.svg')
+        self.__nextBtn.setShortcut('Ctrl+D')
 
         self.__prevBtn.clicked.connect(self.prev)
         self.__nextBtn.clicked.connect(self.next)
